==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/CheckboxBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CheckboxBaseLabelPosition_$type } from "./CheckboxBaseLabelPosition";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let CheckboxBase = /*@__PURE__*/ (() => {
    class CheckboxBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.e = new WCNativeHelper();
            this.k = null;
            this.change = null;
            this.focus = null;
            this.blur = null;
        }
        get f() {
            return this.e;
        }
        get nativeElement() {
            return this.k;
        }
        set nativeElement(a) {
            this.k = a;
            this.e.n = this.k;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get n() {
            let ret_ = this.f.m("name");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.f.u("name", value_);
        }
        get o() {
            let ret_ = this.f.m("value");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.f.u("value", value_);
        }
        get h() {
            let ret_ = this.f.m("disabled");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.f.u("disabled", value_);
        }
        get g() {
            let ret_ = this.f.m("checked");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.f.u("checked", value_);
        }
        get j() {
            let ret_ = this.f.m("required");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.f.u("required", value_);
        }
        get i() {
            let ret_ = this.f.m("invalid");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.f.u("invalid", value_);
        }
        get a() {
            let ret_ = this.f.m("labelPosition");
            ret_ = enumGetBox(CheckboxBaseLabelPosition_$type, EnumUtil.getEnumValue(CheckboxBaseLabelPosition_$type, this.f.f(CheckboxBaseLabelPosition_$type, ret_)));
            return EnumUtil.getEnumValue(CheckboxBaseLabelPosition_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(CheckboxBaseLabelPosition_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("labelPosition", value_);
        }
        get m() {
            let ret_ = this.f.m("ariaLabelledby");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.f.u("ariaLabelledby", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.f.q("change", (a) => this.change(this, ComponentBoolValueChangedEventArgs.a(a)));
            }
            else {
                this.f.t("change");
            }
        }
        focusChanged() {
            if (this.focus != null) {
                this.f.q("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.t("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.f.q("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.t("blur");
            }
        }
        t() {
            this.nativeElement.click();
        }
        x(a) {
            this.nativeElement.focus(this.f.h(a));
        }
        q() {
            this.nativeElement.blur();
        }
        y() {
            this.nativeElement.reportValidity();
        }
        s() {
            this.nativeElement.checkValidity();
        }
        z(a) {
            this.nativeElement.setCustomValidity(this.f.h(a));
        }
        u() {
            this.nativeElement.connectedCallback();
        }
        v() {
            this.nativeElement.disconnectedCallback();
        }
    }
    CheckboxBase.$t = /*@__PURE__*/ markType(CheckboxBase, 'CheckboxBase', BaseElement.$);
    return CheckboxBase;
})();

==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/CheckboxBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CheckboxBaseLabelPosition_$type } from "./CheckboxBaseLabelPosition";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let CheckboxBase = /*@__PURE__*/ (() => {
    class CheckboxBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.e = new WCNativeHelper();
            this.k = null;
            this.change = null;
            this.focus = null;
            this.blur = null;
        }
        get f() {
            return this.e;
        }
        get nativeElement() {
            return this.k;
        }
        set nativeElement(a) {
            this.k = a;
            this.e.o = this.k;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get m() {
            let ret_ = this.f.n("value");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.f.v("value", value_);
        }
        get g() {
            let ret_ = this.f.n("checked");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.f.v("checked", value_);
        }
        get a() {
            let ret_ = this.f.n("labelPosition");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(CheckboxBaseLabelPosition_$type, EnumUtil.getEnumValue(CheckboxBaseLabelPosition_$type, this.f.f(CheckboxBaseLabelPosition_$type, ret_)));
            return EnumUtil.getEnumValue(CheckboxBaseLabelPosition_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(CheckboxBaseLabelPosition_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("labelPosition", value_);
        }
        get h() {
            let ret_ = this.f.n("disabled");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.f.v("disabled", value_);
        }
        get j() {
            let ret_ = this.f.n("required");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.f.v("required", value_);
        }
        get i() {
            let ret_ = this.f.n("invalid");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.f.v("invalid", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.f.r("change", (a) => this.change(this, ComponentBoolValueChangedEventArgs.a(a)));
            }
            else {
                this.f.u("change");
            }
        }
        focusChanged() {
            if (this.focus != null) {
                this.f.r("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.u("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.f.r("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.u("blur");
            }
        }
        r() {
            this.nativeElement.click();
        }
        t(a) {
            this.nativeElement.focus(this.f.i(a));
        }
        o() {
            this.nativeElement.blur();
        }
        u() {
            this.nativeElement.reportValidity();
        }
        q() {
            this.nativeElement.checkValidity();
        }
        v(a) {
            this.nativeElement.setCustomValidity(this.f.i(a));
        }
    }
    CheckboxBase.$t = /*@__PURE__*/ markType(CheckboxBase, 'CheckboxBase', BaseElement.$);
    return CheckboxBase;
})();
